/* show-ipx.cc
 */
#include "osl/record/kisen.h"
#include "osl/misc/eucToLang.h"
#include <iostream>
using namespace osl;

int main(int argc, char **argv)
{
  for (int i=1; i<argc; ++i) {
    KisenIpxFile ipx(argv[i]);
    for (size_t j=0; j<ipx.size(); ++j) {
      if (ipx.getStartDate(j).is_special())
	std::cout << "N/A\t";
      else
	std::cout << ipx.getStartDate(j).year() << "\t";
      std::cout << misc::eucToLang(ipx.getPlayer(j, BLACK)) << "\t" 
		<< misc::eucToLang(ipx.getTitle(j, BLACK)) << "\t"
		<< ipx.getRating(j, BLACK) << "\t";
      std::cout << misc::eucToLang(ipx.getPlayer(j, WHITE)) << "\t" 
		<< misc::eucToLang(ipx.getTitle(j, WHITE)) << "\t"
		<< ipx.getRating(j, WHITE) << "\n";
    }
  }

  return 0;
}

/* ------------------------------------------------------------------------- */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
